@@ -27,8 +27,8 @@
 
 namespace QtLua {
 
-  EnumIterator::EnumIterator(State &ls, QMetaEnum me)
-    : _ls(&ls),
+  EnumIterator::EnumIterator(State *ls, QMetaEnum me)
+    : _ls(ls),
       _me(me),
       _index(0)
   {
