@@ -45,19 +45,18 @@ String Function::get_description() const
   return "";
 }
 
-void Function::register_(State &ls, const String &path)
+void Function::register_(State *ls, const String &path)
 {
-  ls.set_global(path, Value(ls, *this));
+  ls->set_global(path, Value(ls, *this));
 }
 
 void Function::register_(Plugin &plugin, const String &name)
 {
-  if (_loader_ref.valid()) {
-    assert(_loader_ref->instance() == plugin._loader->instance());
-  }
+  if (ref_is_delegate())
+    QTLUA_THROW(QtLua::Function, "The `%' function is already registered on a plugin. Plugin already loaded?", .arg(name));
 
-  _loader_ref = plugin._loader;
-  plugin._map.insert(name, *this);
+  ref_delegate(&plugin);
+  plugin._map.insert(name, this);
 }
 
 void Function::completion_patch(String &path, String &entry, int &offset)
@@ -77,13 +76,5 @@ bool Function::support(Value::Operation c) const
     }
 }
 
-void Function::ref_drop(int count)
-{
-  // Drop reference to plugin loader if statically defined Function
-  // is not used anymore.
-  if (count == 0)
-    _loader_ref.invalidate();
-}
-
 }
 
