@@ -657,7 +657,11 @@ QByteArray ValueBase::to_bytecode() const
   if (lua_type(lst, -1) == LUA_TFUNCTION)
     {
       QByteArray bytecode;
-      int status = lua_dump(lst, &lua_writer, &bytecode);	
+#if LUA_VERSION_NUM >= 503
+      int status = lua_dump(lst, &lua_writer, &bytecode, 0);
+#else
+      int status = lua_dump(lst, &lua_writer, &bytecode);
+#endif
       lua_pop(lst, 1);
       if (status)
 	QTLUA_THROW(QtLua::ValueBase, "Unable to dump function bytecode (status=%)", .arg(status));
@@ -989,6 +993,23 @@ bool ValueBase::operator==(double n) const
   return res;
 }
 
+uint qHash(const ValueBase &lv)
+{
+  if (!lv._st)
+    return 0;
+
+  lua_State *lst = lv._st->get_lua_state();
+  try {
+    lv.push_value(lst);
+  } catch (...) {
+    return 0;
+  }
+
+  uint	res = ValueBase::qHash(lst, -1);
+  lua_pop(lst, 1);
+  return res;
+}
+
 uint ValueBase::qHash(lua_State *lst, int index)
 {
   switch (lua_type(lst, index))
